@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result::Bolt;
 # ABSTRACT: Bolt result handler
-$Neo4j::Driver::Result::Bolt::VERSION = '0.44';
+$Neo4j::Driver::Result::Bolt::VERSION = '0.45';
 
 # This package is not part of the public Neo4j::Driver API.
 
@@ -18,8 +18,9 @@ use List::Util ();
 
 use Neo4j::Driver::Net::Bolt;
 
-my @valid_bolt_neo4j_types = qw(
-	JSON::PP::Boolean
+my ($FALSE, $TRUE) = Neo4j::Driver::Result->_bool_values;
+
+my @valid_bolt_neo4j_types = qw( Neo4j::Bolt::Bytes
 	Neo4j::Bolt::DateTime
 	Neo4j::Bolt::Duration
 	Neo4j::Bolt::Point
@@ -195,6 +196,9 @@ sub _deep_bless {
 	if (ref $data eq '') {  # scalar
 		return $data;
 	}
+	if (ref $data eq 'JSON::PP::Boolean') {
+		return $data ? $TRUE : $FALSE;
+	}
 	if ( List::Util::first { ref $data eq $_ } @valid_bolt_neo4j_types ) {
 		return $data;
 	}
